==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-kbindicator/kbindicator_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Content</name>
    <message>
        <location filename="../../../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translatorcomment>This capital letter is printed on my keyboard.</translatorcomment>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Etiket voor CapsLock-indicator</comment>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translatorcomment>This digit is printed on my keyboard.</translatorcomment>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Etiket voor NumLock-indicator</comment>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translatorcomment>From the word &quot;Rollen&quot;.</translatorcomment>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Etiket voor ScrollLock-indicator</comment>
        <translation>Schuiven</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation>Indeling</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Toetsenbordstatus-instellingen</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Vergrendelingsindicatoren</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Toon Caps Lock-toets</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Toon Num Lock-toets</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Toon Scroll Lock-toets</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Indicator voor toetsenbordindeling</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Omschakelingsbeleid</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation>Indelingen instellen</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Systeembreed</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Toepassing</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-kbindicator/kbindicator_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Content</name>
    <message>
        <location filename="../../../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translatorcomment>This capital letter is printed on my keyboard.</translatorcomment>
        <translation>A</translation>
    </message>
    <message>
        <source>CapsLock</source>
        <comment>Etiket voor CapsLock-indicator</comment>
        <translation type="vanished">A</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translatorcomment>This digit is printed on my keyboard.</translatorcomment>
        <translation>1</translation>
    </message>
    <message>
        <source>NumLock</source>
        <comment>Etiket voor NumLock-indicator</comment>
        <translation type="vanished">1</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translatorcomment>From the word &quot;Rollen&quot;.</translatorcomment>
        <translation>R</translation>
    </message>
    <message>
        <source>ScrollLock</source>
        <comment>Etiket voor ScrollLock-indicator</comment>
        <translation type="vanished">Schuiven</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation type="unfinished">A</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation type="unfinished">1</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation type="unfinished">Schuiven</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation>Indeling</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Toetsenbordstatus-instellingen</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Vergrendelingsindicatoren</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Toon Caps Lock-toets</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Toon Num Lock-toets</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Toon Scroll Lock-toets</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Indicator voor toetsenbordindeling</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Omschakelingsbeleid</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation>Indelingen instellen</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Systeembreed</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Toepassing</translation>
    </message>
</context>
</TS>
